@@ -21,8 +21,9 @@ from importlib import reload
 from logging import ERROR, WARNING
 from random import randint
 from time import time_ns
-from typing import Optional, Sequence
+from typing import Optional
 from unittest import mock
+from unittest.mock import Mock
 
 from opentelemetry import trace as trace_api
 from opentelemetry.context import Context
@@ -39,17 +40,14 @@ from opentelemetry.sdk.environment_variables import (
     OTEL_TRACES_SAMPLER,
     OTEL_TRACES_SAMPLER_ARG,
 )
-from opentelemetry.sdk.trace import Resource
+from opentelemetry.sdk.trace import Resource, TracerProvider
 from opentelemetry.sdk.trace.id_generator import RandomIdGenerator
 from opentelemetry.sdk.trace.sampling import (
     ALWAYS_OFF,
     ALWAYS_ON,
     Decision,
     ParentBased,
-    Sampler,
-    SamplingResult,
     StaticSampler,
-    TraceIdRatioBased,
 )
 from opentelemetry.sdk.util import ns_to_iso_str
 from opentelemetry.sdk.util.instrumentation import InstrumentationInfo
@@ -57,12 +55,15 @@ from opentelemetry.test.spantestutil import (
     get_span_with_dropped_attributes_events_links,
     new_tracer,
 )
-from opentelemetry.trace import Link, SpanKind, Status, StatusCode
-from opentelemetry.trace.span import TraceState
-from opentelemetry.util.types import Attributes
+from opentelemetry.trace import Status, StatusCode
 
 
 class TestTracer(unittest.TestCase):
+    def test_no_deprecated_warning(self):
+        with self.assertRaises(AssertionError):
+            with self.assertWarns(DeprecationWarning):
+                TracerProvider(Mock(), Mock()).get_tracer(Mock(), Mock())
+
     def test_extends_api(self):
         tracer = new_tracer()
         self.assertIsInstance(tracer, trace.Tracer)
@@ -151,78 +152,6 @@ tracer_provider.add_span_processor(mock_processor)
         )
 
 
-class CustomSampler(Sampler):
-    def __init__(self) -> None:
-        pass
-
-    def get_description(self) -> str:
-        return "CustomSampler"
-
-    def should_sample(
-        self,
-        parent_context: Optional["Context"],
-        trace_id: int,
-        name: str,
-        kind: SpanKind = None,
-        attributes: Attributes = None,
-        links: Sequence[Link] = None,
-        trace_state: TraceState = None,
-    ) -> "SamplingResult":
-        return SamplingResult(
-            Decision.RECORD_AND_SAMPLE,
-            None,
-            None,
-        )
-
-
-class CustomRatioSampler(TraceIdRatioBased):
-    def __init__(self, ratio):
-        self.ratio = ratio
-        super().__init__(ratio)
-
-    def get_description(self) -> str:
-        return "CustomSampler"
-
-    def should_sample(
-        self,
-        parent_context: Optional["Context"],
-        trace_id: int,
-        name: str,
-        kind: SpanKind = None,
-        attributes: Attributes = None,
-        links: Sequence[Link] = None,
-        trace_state: TraceState = None,
-    ) -> "SamplingResult":
-        return SamplingResult(
-            Decision.RECORD_AND_SAMPLE,
-            None,
-            None,
-        )
-
-
-class CustomSamplerFactory:
-    @staticmethod
-    def get_custom_sampler(unused_sampler_arg):
-        return CustomSampler()
-
-    @staticmethod
-    def get_custom_ratio_sampler(sampler_arg):
-        return CustomRatioSampler(float(sampler_arg))
-
-    @staticmethod
-    def empty_get_custom_sampler(sampler_arg):
-        return
-
-
-class IterEntryPoint:
-    def __init__(self, name, class_type):
-        self.name = name
-        self.class_type = class_type
-
-    def load(self):
-        return self.class_type
-
-
 class TestTracerSampling(unittest.TestCase):
     def tearDown(self):
         reload(trace)
@@ -251,7 +180,8 @@ class TestTracerSampling(unittest.TestCase):
         tracer_provider = trace.TracerProvider()
         self.verify_default_sampler(tracer_provider)
 
-    def test_sampler_no_sampling(self):
+    @mock.patch("opentelemetry.sdk.trace.sampling._get_from_env_or_default")
+    def test_sampler_no_sampling(self, _get_from_env_or_default):
         tracer_provider = trace.TracerProvider(ALWAYS_OFF)
         tracer = tracer_provider.get_tracer(__name__)
 
@@ -270,6 +200,7 @@ class TestTracerSampling(unittest.TestCase):
             child_span.get_span_context().trace_flags,
             trace_api.TraceFlags.DEFAULT,
         )
+        self.assertFalse(_get_from_env_or_default.called)
 
     @mock.patch.dict("os.environ", {OTEL_TRACES_SAMPLER: "always_off"})
     def test_sampler_with_env(self):
@@ -299,161 +230,6 @@ class TestTracerSampling(unittest.TestCase):
         self.assertIsInstance(tracer_provider.sampler, ParentBased)
         self.assertEqual(tracer_provider.sampler._root.rate, 0.25)
 
-    @mock.patch.dict(
-        "os.environ", {OTEL_TRACES_SAMPLER: "non_existent_entry_point"}
-    )
-    def test_sampler_with_env_non_existent_entry_point(self):
-        # pylint: disable=protected-access
-        reload(trace)
-        tracer_provider = trace.TracerProvider()
-        self.verify_default_sampler(tracer_provider)
-
-    @mock.patch("opentelemetry.sdk.trace.util.iter_entry_points")
-    @mock.patch.dict(
-        "os.environ", {OTEL_TRACES_SAMPLER: "custom_sampler_factory"}
-    )
-    def test_custom_sampler_with_env(self, mock_iter_entry_points):
-        mock_iter_entry_points.return_value = [
-            IterEntryPoint(
-                "custom_sampler_factory",
-                CustomSamplerFactory.get_custom_sampler,
-            )
-        ]
-        # pylint: disable=protected-access
-        reload(trace)
-        tracer_provider = trace.TracerProvider()
-        self.assertIsInstance(tracer_provider.sampler, CustomSampler)
-
-    @mock.patch("opentelemetry.sdk.trace.util.iter_entry_points")
-    @mock.patch.dict(
-        "os.environ", {OTEL_TRACES_SAMPLER: "custom_sampler_factory"}
-    )
-    def test_custom_sampler_with_env_bad_factory(self, mock_iter_entry_points):
-        mock_iter_entry_points.return_value = [
-            IterEntryPoint(
-                "custom_sampler_factory",
-                CustomSamplerFactory.empty_get_custom_sampler,
-            )
-        ]
-        # pylint: disable=protected-access
-        reload(trace)
-        tracer_provider = trace.TracerProvider()
-        self.verify_default_sampler(tracer_provider)
-
-    @mock.patch("opentelemetry.sdk.trace.util.iter_entry_points")
-    @mock.patch.dict(
-        "os.environ",
-        {
-            OTEL_TRACES_SAMPLER: "custom_sampler_factory",
-            OTEL_TRACES_SAMPLER_ARG: "0.5",
-        },
-    )
-    def test_custom_sampler_with_env_unused_arg(self, mock_iter_entry_points):
-        mock_iter_entry_points.return_value = [
-            IterEntryPoint(
-                "custom_sampler_factory",
-                CustomSamplerFactory.get_custom_sampler,
-            )
-        ]
-        # pylint: disable=protected-access
-        reload(trace)
-        tracer_provider = trace.TracerProvider()
-        self.assertIsInstance(tracer_provider.sampler, CustomSampler)
-
-    @mock.patch("opentelemetry.sdk.trace.util.iter_entry_points")
-    @mock.patch.dict(
-        "os.environ",
-        {
-            OTEL_TRACES_SAMPLER: "custom_ratio_sampler_factory",
-            OTEL_TRACES_SAMPLER_ARG: "0.5",
-        },
-    )
-    def test_custom_ratio_sampler_with_env(self, mock_iter_entry_points):
-        mock_iter_entry_points.return_value = [
-            IterEntryPoint(
-                "custom_ratio_sampler_factory",
-                CustomSamplerFactory.get_custom_ratio_sampler,
-            )
-        ]
-        # pylint: disable=protected-access
-        reload(trace)
-        tracer_provider = trace.TracerProvider()
-        self.assertIsInstance(tracer_provider.sampler, CustomRatioSampler)
-        self.assertEqual(tracer_provider.sampler.ratio, 0.5)
-
-    @mock.patch("opentelemetry.sdk.trace.util.iter_entry_points")
-    @mock.patch.dict(
-        "os.environ",
-        {
-            OTEL_TRACES_SAMPLER: "custom_ratio_sampler_factory",
-            OTEL_TRACES_SAMPLER_ARG: "foobar",
-        },
-    )
-    def test_custom_ratio_sampler_with_env_bad_arg(
-        self, mock_iter_entry_points
-    ):
-        mock_iter_entry_points.return_value = [
-            IterEntryPoint(
-                "custom_ratio_sampler_factory",
-                CustomSamplerFactory.get_custom_ratio_sampler,
-            )
-        ]
-        # pylint: disable=protected-access
-        reload(trace)
-        tracer_provider = trace.TracerProvider()
-        self.verify_default_sampler(tracer_provider)
-
-    @mock.patch("opentelemetry.sdk.trace.util.iter_entry_points")
-    @mock.patch.dict(
-        "os.environ",
-        {
-            OTEL_TRACES_SAMPLER: "custom_ratio_sampler_factory",
-        },
-    )
-    def test_custom_ratio_sampler_with_env_no_arg(
-        self, mock_iter_entry_points
-    ):
-        mock_iter_entry_points.return_value = [
-            IterEntryPoint(
-                "custom_ratio_sampler_factory",
-                CustomSamplerFactory.get_custom_ratio_sampler,
-            )
-        ]
-        # pylint: disable=protected-access
-        reload(trace)
-        tracer_provider = trace.TracerProvider()
-        self.verify_default_sampler(tracer_provider)
-
-    @mock.patch("opentelemetry.sdk.trace.util.iter_entry_points")
-    @mock.patch.dict(
-        "os.environ",
-        {
-            OTEL_TRACES_SAMPLER: "custom_sampler_factory",
-            OTEL_TRACES_SAMPLER_ARG: "0.5",
-        },
-    )
-    def test_custom_ratio_sampler_with_env_multiple_entry_points(
-        self, mock_iter_entry_points
-    ):
-        mock_iter_entry_points.return_value = [
-            IterEntryPoint(
-                "custom_ratio_sampler_factory",
-                CustomSamplerFactory.get_custom_ratio_sampler,
-            ),
-            IterEntryPoint(
-                "custom_sampler_factory",
-                CustomSamplerFactory.get_custom_sampler,
-            ),
-            IterEntryPoint(
-                "custom_z_sampler_factory",
-                CustomSamplerFactory.empty_get_custom_sampler,
-            ),
-        ]
-        # pylint: disable=protected-access
-        reload(trace)
-        tracer_provider = trace.TracerProvider()
-        self.assertIsInstance(tracer_provider.sampler, CustomSampler)
-
     def verify_default_sampler(self, tracer_provider):
         self.assertIsInstance(tracer_provider.sampler, ParentBased)
         # pylint: disable=protected-access
